<?php
include '../../includes/db.php';
include '../../includes/functions.php';
check_admin();

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $id = sanitize_input($_POST['id']);
    $name = sanitize_input($_POST['name']);
    $features = sanitize_input($_POST['features']);
    $monthly_price = sanitize_input($_POST['monthly_price']);
    $yearly_price = sanitize_input($_POST['yearly_price']);

    $stmt = $conn->prepare("UPDATE packages SET name = ?, features = ?, monthly_price = ?, yearly_price = ? WHERE id = ?");
    $stmt->execute([$name, $features, $monthly_price, $yearly_price, $id]);

    header('Location: manage_packages.php');
    exit();
} else {
    $id = sanitize_input($_GET['id']);
    $stmt = $conn->prepare("SELECT * FROM packages WHERE id = ?");
    $stmt->execute([$id]);
    $package = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$package) {
        header('Location: manage_packages.php');
        exit();
    }
}

$pageTitle = "Edit Package";
include '../includes/header.php';
include '../includes/sidebar.php';
include '../includes/topbar.php';
?>
<!-- Begin Page Content -->
<div class="container-fluid">
    <!-- Page Heading -->
    <div class="d-sm-flex align-items-center justify-content-between mb-4">
        <h1 class="h3 mb-0 text-gray-800">Edit Package</h1>
    </div>

    <!-- Content Row -->
    <div class="row">
        <div class="col-lg-12">
            <div class="card shadow mb-4">
                <div class="card-header py-3">
                    <h6 class="m-0 font-weight-bold text-primary">Edit Package Details</h6>
                </div>
                <div class="card-body">
                    <form method="post" action="">
                        <input type="hidden" name="id" value="<?php echo htmlspecialchars($package['id']); ?>">
                        <div class="form-group">
                            <label for="name">Package Name</label>
                            <input type="text" class="form-control" id="name" name="name" value="<?php echo htmlspecialchars($package['name']); ?>" required>
                        </div>
                        <div class="form-group">
                            <label for="features">Features</label>
                            <textarea class="form-control" id="features" name="features" rows="3" required><?php echo htmlspecialchars($package['features']); ?></textarea>
                        </div>
                        <div class="form-group">
                            <label for="monthly_price">Monthly Price</label>
                            <input type="number" step="0.01" class="form-control" id="monthly_price" name="monthly_price" value="<?php echo htmlspecialchars($package['monthly_price']); ?>" required>
                        </div>
                        <div class="form-group">
                            <label for="yearly_price">Yearly Price</label>
                            <input type="number" step="0.01" class="form-control" id="yearly_price" name="yearly_price" value="<?php echo htmlspecialchars($package['yearly_price']); ?>" required>
                        </div>
                        <button type="submit" class="btn btn-primary">Update Package</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>
<!-- /.container-fluid -->

<?php include '../includes/footer.php'; ?>
