<?php
include '../../includes/db.php';
include '../../includes/functions.php';
include '../../includes/smtp_config.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $email = sanitize_input($_POST['email']);

    // Check if admin exists
    $stmt = $conn->prepare("SELECT * FROM admins WHERE email = ?");
    $stmt->execute([$email]);
    $admin = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($admin) {
        $token = bin2hex(random_bytes(50));
        $stmt = $conn->prepare("UPDATE admins SET reset_token = ? WHERE email = ?");
        $stmt->execute([$token, $email]);

        // Send reset email
        $reset_link = "https://yourdomain.com/admin/pages/reset_password.php?token=$token";
        $subject = "Password Reset Request";
        $body = "Hi " . htmlspecialchars($admin['name']) . ",<br><br>";
        $body .= "We received a request to reset your password. Click the link below to reset your password:<br>";
        $body .= "<a href='$reset_link'>$reset_link</a><br><br>";
        $body .= "If you did not request a password reset, please ignore this email.<br><br>";
        $body .= "Thanks,<br>Your Team";

        send_email($email, $subject, $body);

        $success_message = "An email has been sent to your email address with instructions to reset your password.";
    } else {
        $error_message = "No account found with that email address.";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <title>Admin Forgot Password</title>
    <link href="../assets/css/bootstrap.min.css" rel="stylesheet">
    <link href="../assets/css/sb-admin-2.min.css" rel="stylesheet">
    <link href="../assets/css/custom.css" rel="stylesheet">
</head>
<body class="bg-gradient-primary">
    <div class="container">
        <div class="row justify-content-center">
            <div class="col-xl-10 col-lg-12 col-md-9">
                <div class="card o-hidden border-0 shadow-lg my-5">
                    <div class="card-body p-0">
                        <div class="row">
                            <div class="col-lg-6 d-none d-lg-block bg-password-image"></div>
                            <div class="col-lg-6">
                                <div class="p-5">
                                    <div class="text-center">
                                        <h1 class="h4 text-gray-900 mb-4">Forgot Your Password?</h1>
                                    </div>
                                    <?php if (isset($error_message)): ?>
                                        <div class="alert alert-danger"><?php echo htmlspecialchars($error_message); ?></div>
                                    <?php elseif (isset($success_message)): ?>
                                        <div class="alert alert-success"><?php echo htmlspecialchars($success_message); ?></div>
                                    <?php endif; ?>
                                    <form class="user" method="post" action="">
                                        <div class="form-group">
                                            <input type="email" class="form-control form-control-user" name="email" placeholder="Enter Email Address..." required>
                                        </div>
                                        <button type="submit" class="btn btn-primary btn-user btn-block">
                                            Reset Password
                                        </button>
                                    </form>
                                    <hr>
                                    <div class="text-center">
                                        <a class="small" href="login.php">Remembered your password? Login!</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <script src="../assets/js/jquery.min.js"></script>
    <script src="../assets/js/bootstrap.bundle.min.js"></script>
    <script src="../assets/js/sb-admin-2.min.js"></script>
    <script src="../assets/js/custom.js"></script>
</body>
</html>

