<?php
include('../../includes/db.php');
include('../../includes/functions.php');

session_start();

$error_message = "";

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['register'])) {
        $name = sanitize_input($_POST['name']);
        $email = sanitize_input($_POST['email']);
        $password = sanitize_input($_POST['password']);
        $repeat_password = sanitize_input($_POST['repeat_password']);

        if ($password !== $repeat_password) {
            $error_message = "Passwords do not match.";
        } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
            $error_message = "Invalid email format";
        } else {
            $hashed_password = password_hash($password, PASSWORD_BCRYPT);

            $stmt = $conn->prepare("INSERT INTO users (name, email, password) VALUES (?, ?, ?)");
            try {
                $stmt->execute([$name, $email, $hashed_password]);
                $_SESSION['user_id'] = $conn->lastInsertId();
                $_SESSION['role'] = 'user'; // Default role
                $_SESSION['name'] = $name;
                header("Location: ../../pages/user/dashboard.php");
                exit();
            } catch (PDOException $e) {
                if ($e->errorInfo[1] == 1062) {
                    $error_message = "Email already exists";
                } else {
                    $error_message = "Database error: " . $e->getMessage();
                }
            }
        }
    }
}

$pageTitle = "Register";
include('../../includes/header.php');
?>

<div class="container">
    <div class="row justify-content-center">
        <div class="col-xl-10 col-lg-12 col-md-9">
            <div class="card o-hidden border-0 shadow-lg my-5">
                <div class="card-body p-0">
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="p-5">
                                <div class="text-center">
                                    <h1 class="h4 text-gray-900 mb-4">Create an Account!</h1>
                                </div>
                                <?php if (!empty($error_message)): ?>
                                    <div class="alert alert-danger" role="alert">
                                        <?php echo $error_message; ?>
                                    </div>
                                <?php endif; ?>
                                <form class="user" method="post" action="register.php">
                                    <div class="form-group">
                                        <input type="text" class="form-control form-control-user" id="name" placeholder="Name" name="name" required>
                                    </div>
                                    <div class="form-group">
                                        <input type="email" class="form-control form-control-user" id="email" placeholder="Email Address" name="email" required>
                                    </div>
                                    <div class="form-group row">
                                        <div class="col-sm-6 mb-3 mb-sm-0">
                                            <input type="password" class="form-control form-control-user" id="password" placeholder="Password" name="password" required>
                                        </div>
                                        <div class="col-sm-6">
                                            <input type="password" class="form-control form-control-user" id="repeatPassword" placeholder="Repeat Password" name="repeat_password" required>
                                        </div>
                                    </div>
                                    <button type="submit" name="register" class="btn btn-primary btn-user btn-block">Register Account</button>
                                </form>
                                <hr>
                                <div class="text-center">
                                    <a class="small" href="forgot-password.php">Forgot Password?</a>
                                </div>
                                <div class="text-center">
                                    <a class="small" href="login.php">Already have an account? Login!</a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php
include('../../includes/footer.php');
?>
