<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

$user_id = $_SESSION['user_id'];

// Fetch user's current subscription
$stmt = $conn->prepare("
    SELECT 
        subscriptions.*, 
        packages.name AS package_name,
        packages.website_limit,
        packages.bandwidth_limit,
        CASE 
            WHEN subscriptions.billing_cycle = 'monthly' THEN packages.monthly_price 
            WHEN subscriptions.billing_cycle = 'yearly' THEN packages.yearly_price 
        END AS package_price 
    FROM subscriptions 
    JOIN packages ON subscriptions.package_id = packages.id 
    WHERE subscriptions.user_id = ? AND subscriptions.status = 'Active'
");
$stmt->execute([$user_id]);
$current_subscription = $stmt->fetch(PDO::FETCH_ASSOC);

// Fetch the number of websites created by the user
$stmt = $conn->prepare("SELECT COUNT(*) AS website_count FROM cdn_websites WHERE user_id = ?");
$stmt->execute([$user_id]);
$website_count = $stmt->fetch(PDO::FETCH_ASSOC)['website_count'];

// Determine the website limit
$website_limit = $current_subscription ? $current_subscription['website_limit'] : 0;
$bandwidth_limit = $current_subscription ? $current_subscription['bandwidth_limit'] : 0;
$subscription_status = $current_subscription ? $current_subscription['status'] : 'No Active Subscription';
$next_billing_date = $current_subscription ? date('d-M-Y', strtotime($current_subscription['end_date'])) : 'N/A';

// Define status colors
$status_color = [
    'Active' => 'text-success font-weight-bold',
    'Expired' => 'text-danger font-weight-bold',
    'Pending' => 'text-warning font-weight-bold',
    'No Active Subscription' => 'text-muted font-weight-bold'
];

$pageTitle = "Dashboard";
include('../../includes/header.php');
include('../../includes/sidebar.php');
include('../../includes/topbar.php');
?>

<div id="content-wrapper" class="d-flex flex-column">
    <!-- Main Content -->
    <div id="content">
        <div class="container-fluid">
            <h1 class="h3 mb-4 text-gray-800">Dashboard</h1>

            <div class="row">
                <!-- Website Limit Card -->
                <div class="col-xl-4 col-md-6 mb-4">
                    <div class="card border-left-primary shadow h-100 py-2">
                        <div class="card-body">
                            <div class="row no-gutters align-items-center">
                                <div class="col mr-2">
                                    <div class="text-xs font-weight-bold text-primary text-uppercase mb-1">
                                        Website Limit</div>
                                    <div class="h5 mb-0 font-weight-bold text-gray-800"><?php echo $website_count . ' / ' . ($website_limit == -1 ? 'Unlimited' : $website_limit); ?></div>
                                </div>
                                <div class="col-auto">
                                    <i class="fas fa-globe fa-2x text-gray-300"></i>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Bandwidth Limit Card -->
                <div class="col-xl-4 col-md-6 mb-4">
                    <div class="card border-left-success shadow h-100 py-2">
                        <div class="card-body">
                            <div class="row no-gutters align-items-center">
                                <div class="col mr-2">
                                    <div class="text-xs font-weight-bold text-success text-uppercase mb-1">
                                        Bandwidth Limit</div>
                                    <div class="h5 mb-0 font-weight-bold text-gray-800"><?php echo $bandwidth_limit == -1 ? 'Unlimited' : $bandwidth_limit . ' GB'; ?></div>
                                </div>
                                <div class="col-auto">
                                    <i class="fas fa-tachometer-alt fa-2x text-gray-300"></i>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Subscription Status Card -->
                <div class="col-xl-4 col-md-6 mb-4">
                    <div class="card border-left-warning shadow h-100 py-2">
                        <div class="card-body">
                            <div class="row no-gutters align-items-center">
                                <div class="col mr-2">
                                    <div class="text-xs font-weight-bold text-warning text-uppercase mb-1">
                                        Subscription Status</div>
                                    <div class="h5 mb-0 <?php echo $status_color[$subscription_status]; ?>"><?php echo htmlspecialchars($subscription_status); ?></div>
                                    <div class="mt-2 mb-0 text-muted text-xs">
                                        <span>Next Billing Time: <?php echo htmlspecialchars($next_billing_date); ?></span>
                                    </div>
                                </div>
                                <div class="col-auto">
                                    <i class="fas fa-clipboard-list fa-2x text-gray-300"></i>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

            </div>
        </div>
    </div>

    <!-- Footer -->
    <?php include('../../includes/footer.php'); ?>
</div>

<script src="../../assets/js/jquery.min.js"></script>
<script src="../../assets/js/bootstrap.bundle.min.js"></script>
<script src="../../assets/js/sb-admin-2.min.js"></script>
</body>
</html>
